@@ -8,21 +8,15 @@
 """
 import io
 import os
-import sys
 import jsonref
 from jsonpointer import resolve_pointer
-from six import string_types
 from docutils import nodes
 from docutils.parsers.rst import directives, Directive
-from docutils.utils import new_document
-from recommonmark.parser import CommonMarkParser
+from myst_parser.main import to_docutils
 
-if sys.version_info < (2, 7):
-    import simplejson as json
-    from ordereddict import OrderedDict
-else:
-    import json
-    from collections import OrderedDict
+
+import json
+from collections import OrderedDict
 
 
 class CustomJsonrefLoader(jsonref.JsonLoader):
@@ -167,14 +161,10 @@ class JSONSchemaDirective(Directive):
 
     def cell(self, text, morecols=0, source=None):
         entry = nodes.entry(morecols=morecols)
-        if not isinstance(text, string_types):
+        if not isinstance(text, str):
             text = str(text)
 
-        parser = CommonMarkParser()
-        new_doc = new_document(None)
-        parser.parse(text, new_doc)
-
-        for child in new_doc.children[:]:
+        for child in to_docutils(text).children[:]:
             child.source = source
             entry += child
         return entry
@@ -190,7 +180,7 @@ def get_class_for(obj):
         'array': Array,
         'object': Object,
     }
-    if isinstance(obj, string_types):
+    if isinstance(obj, str):
         type = obj
     else:
         type = obj.get('type')
@@ -206,7 +196,7 @@ def simplify(obj):
         type = obj.get('type')
         if type is None:
             return 'null'
-        elif isinstance(type, string_types):
+        elif isinstance(type, str):
             return json.dumps(type)
         else:
             return str(type)
